==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/gg/hgg08.h <==

/*******************************************************************************

  module:       hgg08.h

  ------------------------------------------------------------------------------

  responsible:  ElkeZ

  purpose:      Regions_and_Longwaits

  lastChanged:  2000-03-03

  generatedBy:  $TOOL/bin/ptocProto.py

  ------------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin  GPL
    Copyright (C) 2000 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

********************************************************************************/

#ifndef HGG08_H
#define HGG08_H


/*===========================================================================*
 *     RefType: C++                                                          *
 *===========================================================================*/

/*===========================================================================*
 *     MD5: '\346\223nP\375o\263\351\001\340\345\360\202\321\244)'
 *===========================================================================*/


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externPascal tsp00_RegionId g08backup;
externPascal tsp00_RegionId g08bufwrtr;
externPascal tsp00_RegionId g08datawrtr;
externPascal tsp00_RegionId g08cnstview;
externPascal tsp00_RegionId g08config;
externPascal tsp00_RegionId g08convert;
externPascal tsp00_RegionId g08data1;
externPascal tsp00_RegionId g08datacache;
externPascal tsp_region_id g08dcom;
externPascal tsp_region_id g08diagcache;
externPascal tsp_region_id g08drda;
externPascal tsp_region_id g08fbm;
externPascal tsp00_RegionId g08garbage;
externPascal tsp_region_id g08hash0;
externPascal tsp_region_id g08hashinit;
externPascal tsp_region_id g08into_queue;
externPascal tsp00_RegionId g08lock0;
externPascal tsp00_RegionId g08lockinit;
externPascal tsp00_RegionId g08lockpool;
externPascal tsp00_RegionId g08lockreq;
externPascal tsp00_RegionId g08lockwait;
externPascal tsp00_RegionId g08log;
externPascal tsp00_RegionId g08logwriter;
externPascal tsp_region_id g08monitor;
externPascal tsp00_RegionId g08history;
externPascal tsp00_RegionId g08oms1;
externPascal tsp_region_id g08out_queue;
externPascal tsp00_RegionId g08permfdir;
externPascal tsp00_RegionId g08req_pno;
externPascal tsp00_RegionId g08save0;
externPascal tsp00_RegionId g08server;
externPascal tsp00_RegionId g08split1;
externPascal tsp_region_id g08sproc;
externPascal tsp00_RegionId g08surrogate;
externPascal tsp00_RegionId g08tempfdir;
externPascal tsp00_RegionId g08trace;
externPascal tsp00_RegionId g08tree1;
externPascal tsp00_RegionId g08further_use1;

externPascal void g08check_excl (
    tsp00_RegionId           region);

externPascal void g08excl_check (
    tsp00_TaskId             pid,
    tsp00_RegionId           region);

externPascal void g08region_ids ();


#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/gg/hgg08.h <==

/*******************************************************************************

  module:       hgg08.h

  ------------------------------------------------------------------------------

  responsible:  ElkeZ

  purpose:      Regions_and_Longwaits

  lastChanged:  2003-01-20

  generatedBy:  $TOOL/bin/ptocProto.py

  ------------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999


    ========== licence begin  GPL
    Copyright (C) 2000 SAP AG
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end
********************************************************************************/

#ifndef HGG08_H
#define HGG08_H


/*===========================================================================*
 *     RefType: C++                                                          *
 *===========================================================================*/

/*===========================================================================*
 *     MD5: '\xcb\x3f\x27\xbb\x27\xf3\x9a\x39\x4f\x5b\x98\x2c\x4f\x08\xab\xcb'
 *===========================================================================*/


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externPascal tsp00_RegionId g08backup;
externPascal tsp00_RegionId g08bufwrtr;
externPascal tsp00_RegionId g08datawrtr;
externPascal tsp00_RegionId g08cnstview;
externPascal tsp00_RegionId g08config;
externPascal tsp00_RegionId g08convert0;
externPascal tsp00_RegionId g08data1;
externPascal tsp00_RegionId g08datacache;
externPascal tsp_region_id g08dcom;
externPascal tsp_region_id g08diagcache;
externPascal tsp_region_id g08fbm;
externPascal tsp00_RegionId g08garbage;
externPascal tsp_region_id g08hash0;
externPascal tsp_region_id g08hashinit;
externPascal tsp00_RegionId g08lock0;
externPascal tsp00_RegionId g08lockinit;
externPascal tsp00_RegionId g08lockpool;
externPascal tsp00_RegionId g08lockreq;
externPascal tsp00_RegionId g08lockwait;
externPascal tsp00_RegionId g08savepoint;
externPascal tsp00_RegionId g08logqueue0;
externPascal tsp00_RegionId g08loginfo;
externPascal tsp00_RegionId g08LVCEmergency;
externPascal tsp00_RegionId g08history0;
externPascal tsp00_RegionId g08logwriter;
externPascal tsp_region_id g08monitor;
externPascal tsp00_RegionId g08history;
externPascal tsp00_RegionId g08oms1;
externPascal tsp00_RegionId g08permfdir;
externPascal tsp00_RegionId g08save0;
externPascal tsp00_RegionId g08server;
externPascal tsp00_RegionId g08split1;
externPascal tsp00_RegionId g08surrogate;
externPascal tsp00_RegionId g08trace;
externPascal tsp00_RegionId g08tree1;
externPascal tsp00_RegionId g08TaskWait;
externPascal tsp00_RegionId g08ConvIndex;
externPascal tsp00_RegionId g08ComponentEnd;

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08check_excl (
    tsp00_RegionId           region);

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08excl_check (
    tsp00_TaskId             pid,
    tsp00_RegionId           region);

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08region_ids ();

/* Don't edit this file by hand, it is generated by ptocProto.py */


#endif
